@@ -144,6 +144,10 @@ proc tclInit {} {
 	namespace eval ::vfs { variable tclkit_version 1 }
 	catch { uplevel #0 [list source [file join $mountpoint config.tcl]] }
 
+	# Set-up starkit::tclkitroot
+	namespace eval ::starkit { variable tclkitroot }
+	set ::starkit::tclkitroot $mountpoint
+
 	# Perform expected initialization
 	uplevel #0 [list source [file join $tcl_library init.tcl]]
   
@@ -163,19 +167,17 @@ proc tclInit {} {
 		if {[info exists ::TCLKIT_INITVFS] && [info exists ::tclKitFilename]} {
 			catch {
 				vfs::zip::Mount $::tclKitFilename "/.KITDLL_USER"
-
-				lappend auto_path "/.KITDLL_USER/lib"
 			}
 		}
+		lappend auto_path "/.KITDLL_USER/lib"
 
 		## Mount the VFS from executable
 		if {[info exists ::TCLKIT_INITVFS]} {
 			catch {
 				vfs::zip::Mount [info nameofexecutable] "/.KITDLL_APP"
-
-				lappend auto_path "/.KITDLL_APP/lib"
 			}
 		}
+		lappend auto_path "/.KITDLL_APP/lib"
 	}
 
 	# Clean up
