@@ -21,10 +21,10 @@ PATCHDIR="$(pwd)/patches"
 export TCLVFSVERS SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHDIR
 
 # Set configure options for this sub-project
-LDFLAGS="${KC_TCLVFS_LDFLAGS}"
-CFLAGS="${KC_TCLVFS_CFLAGS}"
-CPPFLAGS="${KC_TCLVFS_CPPFLAGS}"
-LIBS="${KC_TCLVFS_LIBS}"
+LDFLAGS="${LDFLAGS} ${KC_TCLVFS_LDFLAGS}"
+CFLAGS="${CFLAGS} ${KC_TCLVFS_CFLAGS}"
+CPPFLAGS="${CPPFLAGS} ${KC_TCLVFS_CPPFLAGS}"
+LIBS="${LIBS} ${KC_TCLVFS_LIBS}"
 export LDFLAGS CFLAGS CPPFLAGS LIBS
 
 rm -rf 'build' 'out' 'inst'
